pub struct Renderer { /* private fields */ }Expand description
A class used for rendering using any number of render pipelines.
Implementations
Sourceimpl Renderer
impl Renderer
Sourcepub async fn new(window: &Window) -> Result<Self>
pub async fn new(window: &Window) -> Result<Self>
Creates a new renderer given a window.
Requirements:
- any of the supported backends
- all native features must be supported by the rendering device
Sourcepub fn with_camera(self, camera: Camera) -> Self
pub fn with_camera(self, camera: Camera) -> Self
Sets the camera of the renderer.
pub fn add_pipeline(&mut self, pipeline: Box<dyn RenderPipeline>)
Sourcepub fn get_texture(&self, label: &str, texture_path: &Path) -> Result<Texture>
pub fn get_texture(&self, label: &str, texture_path: &Path) -> Result<Texture>
Loads a texture from a file.
Sourcepub async fn render(&mut self) -> Result<(), SurfaceError>
pub async fn render(&mut self) -> Result<(), SurfaceError>
Runs on every iteration of the window’s event_loop. Renders without altering the state of the Renderer.