pub struct Window {
pub window: Window,
pub event_loop: EventLoopProxy<()>,
}Expand description
A type which gives access to a certain window.
Fields
window: a handle to the actual windowevent_loop: a proxy to the event loop. This needs to be a proxy because winit::event_loop_proxy cannot be shared between threads. Used to wake up the actual event loop from another thread.
Fields
window: Windowevent_loop: EventLoopProxy<()>Auto Trait Implementations
impl Freeze for Window
impl !RefUnwindSafe for Window
impl Send for Window
impl Sync for Window
impl Unpin for Window
impl !UnwindSafe for Window